@@ -171,6 +171,27 @@ The volume is a directory
 
 The volume is a network source
 
+=item Sys::Virt::StorageVol::TYPE_NETDIR
+
+The volume is a network directory
+
+=back
+
+=head2 CREATE MODES
+
+The following constants are useful for the C<flags> parameter of
+the C<create> method
+
+=over 4
+
+=item Sys::Virt::StorageVol::CREATE_PREALLOC_METADATA
+
+Preallocate header metadata when creating the volume.
+
+=item Sys::Virt::StorageVol::CREATE_REFLINK
+
+Perform lightweight reference copy
+
 =back
 
 =head2 DELETE MODES
@@ -188,6 +209,10 @@ Do a plain delete without any attempt to scrub data.
 
 Zero out current allocated blocks when deleteing the volume
 
+=item Sys::Virt::StorageVol::DELETE_WITH_SNAPSHOTS
+
+Delete snapshots associated with the volume
+
 =back
 
 =head2 WIPE ALGORITHM CONSTANTS
